@@ -879,12 +879,12 @@ def unpack_env(envkey):
     """ Unpack the appname, possible namespaces, and the key from an environment
         variable key name.
     """
-    appname, *namespaces, key = envkey.lower().split(ENVIRONS_SEP)
+    appname, *namespaces, key = envkey.casefold().split(ENVIRONS_SEP)
     return appname, key, tuple(namespaces)
 
 def nskey_from_env(envkey):
     """ Repack an environment-variable key name as a packed namespace key. """
-    appname, *namespaces, key = envkey.lower().split(ENVIRONS_SEP)
+    appname, *namespaces, key = envkey.casefold().split(ENVIRONS_SEP)
     return appname, pack_ns(key, *namespaces)
 
 def nskey_to_env(appname, nskey):
@@ -902,7 +902,7 @@ def envwalk(appname, mapping):
         the format expected for a “walk(…)” function.
     """
     app_prefix = prefix_env(appname)
-    for envkey in (ek for ek in mapping if ek.startswith(app_prefix)):
+    for envkey in (ek for ek in mapping.keys() if ek.startswith(app_prefix)):
         an, key, namespaces = unpack_env(envkey)
         assert an == appname
         yield listify(namespaces) + listify(key, mapping[envkey])
@@ -1036,44 +1036,51 @@ export(NAMESPACE_SEP, name='NAMESPACE_SEP')
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
 
-def nestedmaps():
-    """ Private nested-dictionary pseudo-fixture """
-    return {'body':   {'declare_i': {'id': {'name': 'i', 'type': 'Identifier'},
-                                            'init': {'type': 'Literal', 'value': 2},
-                                            'type': 'VariableDeclarator'},
-                           'kind': 'var',
-                           'type': 'VariableDeclaration',
-                           'declare_j': {'id': {'name': 'j', 'type': 'Identifier'},
-                                            'init': {'type': 'Literal', 'value': 4},
-                                            'type': 'VariableDeclarator'},
-                           'kind': 'var',
-                           'type': 'VariableDeclaration',
-                           'declare_answer': {'id': {'name': 'answer', 'type': 'Identifier'},
-                                            'init': {'left': {'name': 'i',
-                                                              'type': 'Identifier'},
-                                                     'operator': '*',
-                                                     'right': {'name': 'j',
-                                                               'type': 'Identifier'},
-                                                     'type': 'BinaryExpression'},
-                                            'type': 'VariableDeclarator'},
-                           'kind': 'var',
-                           'type': 'VariableDeclaration'},
-            'type':     'Program'}
-
-def flatdict():
-    """ Private flat-dictionary pseudo-fixture """
-    out = {}
-    for mappingpath in mapwalk(nestedmaps()):
-        *namespaces, key, value = mappingpath
-        nskey = pack_ns(key, *namespaces)
-        out[nskey] = value
-    return out
-
 def test():
     
-    from clu.testing.utils import inline
+    from clu.testing.utils import inline, format_environment
     from pprint import pprint
     
+    @inline.fixture
+    def nestedmaps():
+        """ Private nested-dictionary pseudo-fixture """
+        return {'body':   {'declare_i': {'id': {'name': 'i', 'type': 'Identifier'},
+                                                'init': {'type': 'Literal', 'value': 2},
+                                                'type': 'VariableDeclarator'},
+                               'kind': 'var',
+                               'type': 'VariableDeclaration',
+                               'declare_j': {'id': {'name': 'j', 'type': 'Identifier'},
+                                                'init': {'type': 'Literal', 'value': 4},
+                                                'type': 'VariableDeclarator'},
+                               'kind': 'var',
+                               'type': 'VariableDeclaration',
+                               'declare_answer': {'id': {'name': 'answer', 'type': 'Identifier'},
+                                                'init': {'left': {'name': 'i',
+                                                                  'type': 'Identifier'},
+                                                         'operator': '*',
+                                                         'right': {'name': 'j',
+                                                                   'type': 'Identifier'},
+                                                         'type': 'BinaryExpression'},
+                                                'type': 'VariableDeclarator'},
+                               'kind': 'var',
+                               'type': 'VariableDeclaration'},
+                'type':     'Program'}
+    
+    @inline.fixture
+    def flatdict():
+        """ Private flat-dictionary pseudo-fixture """
+        out = {}
+        for mappingpath in mapwalk(nestedmaps()):
+            *namespaces, key, value = mappingpath
+            nskey = pack_ns(key, *namespaces)
+            out[nskey] = value
+        return out
+    
+    @inline.precheck
+    def show_nestedmaps():
+        print("Nested maps fixture output:")
+        pprint(nestedmaps())
+    
     @inline
     def test_one():
         """ Simple “mapwalk(…)” content """
@@ -1102,9 +1109,12 @@ def test():
             nskey = pack_ns(key, *namespaces)
             flat_dict[nskey] = value
         
+        assert flat_dict == flatdict()
+        
         flat = FrozenFlat(flat_dict)
         nested = Nested(flat)
         assert nested.flatten() == flat
+        assert nested.flatten().dictionary == flatdict()
         assert nested == flat
     
     @inline
@@ -1117,13 +1127,17 @@ def test():
             nskey = pack_ns(key, *namespaces)
             flat_dict[nskey] = value
         
+        assert flat_dict == flatdict()
+        
         flat = Flat(flat_dict)
         frozen_flat = flat.freeze()
         assert frozen_flat == flat
+        assert frozen_flat.dictionary == flatdict()
         
         nested = flat.nestify()
         flattened = nested.flatten()
         assert flattened == flat
+        assert flattened.dictionary == flatdict()
     
     @inline
     def test_four():
@@ -1155,7 +1169,7 @@ def test():
     
     @inline
     def test_five_pt_five():
-        """ Nested (mutable) and FrozenNested roundtrip commutativity """
+        """ Nested (mutable) and FrozenNested commutativity """
         nested = Nested(tree=nestedmaps())
         frozen_nested = nested.freeze()
         assert frozen_nested == nested
@@ -1226,8 +1240,11 @@ def test():
         assert os.getenv('CLU_CTX_YODOGG') is None
         assert len(os.environ) == before
     
-    print()
-    pprint(nestedmaps)
+    @inline.diagnostic
+    def show_environment():
+        """ Show environment variables """
+        for envline in format_environment():
+            print(envline)
     
     # Run all inline tests:
     inline.test(100)
