@@ -434,6 +434,8 @@ def test():
             youlike = fields.String("you like:")
             andalso = fields.Tuple(value=fields.String("«also»", allow_none=False))
     
+    MySchema.wat = fields.String('HAX')
+    
     @inline
     def test_one():
         
@@ -567,7 +569,7 @@ def test():
         print()
     
     # Run all inline tests:
-    inline.test(vars())
+    inline.test(10)
 
 if __name__ == '__main__':
     test()
