@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 from collections import defaultdict as DefaultDict
+from dataclasses import dataclass, field, fields
 from functools import lru_cache
 from itertools import chain
 
 cache = lambda function: lru_cache()(function)
 iterchain = chain.from_iterable
+reprless = dataclass(repr=False)
 
 import abc
 import clu.abstract
@@ -16,6 +18,7 @@ import importlib.machinery
 import inspect
 import pkgutil
 import sys
+import typing as tx
 import weakref
 import zict
 
@@ -27,8 +30,9 @@ except ImportError:
 
 from clu.constants import consts
 from clu.extending import Extensible
-from clu.naming import nameof, dotpath_split, dotpath_join
-from clu.predicates import attr, attr_search, mro
+from clu.naming import nameof, moduleof, dotpath_split, dotpath_join, qualified_name
+from clu.predicates import anyattrs, attr, attr_search, item_search, mro, tuplize
+from clu.repr import stringify
 from clu.typespace import Namespace, types
 from clu.typology import ismodule, ismapping, isstring, subclasscheck
 from clu.exporting import Registry as ExporterRegistry
@@ -77,6 +81,14 @@ class MetaRegistry(Extensible):
         """ Allows lookup of an app name through subscripting the Registry class """
         return Registry.for_appname(key)
     
+    def __repr__(cls):
+        """ Type repr definition for class-based modules and ancestors """
+        qualname = getattr(cls, 'qualname', None)
+        if not qualname:
+            module = moduleof(cls)
+            return f"<class-module ancestor type “{module}.{cls.__name__}”>"
+        return f"<class-module “{cls.qualname}”>"
+    
     @staticmethod
     def unregister(appname, qualified_name):
         """ Unregister a previously-registered per-appname class from the registry """
@@ -188,8 +200,23 @@ class Package(types.Module):
         out += ">"
         return out
 
+class MetaTypeRepr(abc.ABCMeta):
+    
+    """ At the time of writing, type-specific “__repr__(…)” definitions
+        require the use of a metaclass – soooooooo…
+    """
+    
+    def __repr__(cls):
+        qualname = qualified_name(cls)
+        appname = getattr(cls, 'appname', None)
+        if appname is None:
+            return f"<class “{qualname}”>"
+        return f"<class “{qualname}” from “{appname}”>"
+
 @export
-class FinderBase(clu.abstract.AppName, importlib.abc.MetaPathFinder):
+class FinderBase(clu.abstract.AppName,
+                 importlib.abc.MetaPathFinder,
+                 metaclass=MetaTypeRepr):
     
     """ The base class for all class-based module finders.
         
@@ -241,7 +268,9 @@ class FinderBase(clu.abstract.AppName, importlib.abc.MetaPathFinder):
                     for module in modules_for_appname(cls.appname))
 
 @export
-class LoaderBase(clu.abstract.AppName, importlib.abc.Loader):
+class LoaderBase(clu.abstract.AppName,
+                 importlib.abc.Loader,
+                 metaclass=MetaTypeRepr):
     
     """ The base class for all class-based module loaders.
         
@@ -301,6 +330,13 @@ class LoaderBase(clu.abstract.AppName, importlib.abc.Loader):
                     raise TypeError("__execute__() method not callable")
             else:
                 module._executed = True
+    
+    def __repr__(self):
+        qualname = qualified_name(self)
+        appname = getattr(self, 'appname', None)
+        if appname is None:
+            return f"<loader “{qualname}”>"
+        return f"<loader “{qualname}” from “{appname}”>"
 
 @export
 class ArgumentSink(object):
@@ -355,7 +391,7 @@ class MetaModule(MetaRegistry):
     
     @property
     def prefix(cls):
-        if any(field is None for field in (cls.appname, cls.appspace)):
+        if any(attrib is None for attrib in (cls.appname, cls.appspace)):
             if cls.appname:
                 return cls.appname
             if cls.appspace:
@@ -519,17 +555,105 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
                       super(ModuleBase, self).__dir__())
         return sorted(frozenset(names) - DO_NOT_INCLUDE)
 
+@reprless
+class PerApp:
+    
+    """ Dataclass representing an “app”, as per the notion of
+        an “appname”, and the related subtypes pertaining to
+        said app: a Finder, a Loader, and one or more Modules
+        (each of the latter of which possessing a distinct
+        “appspace” label).
+    """
+    
+    loader:  Extensible
+    finder:  Extensible
+    modules: tx.Mapping[str, MetaModule] = field(default_factory=dict)
+    appname: str                         = field(default_factory=str)
+    
+    def appspaces(self):
+        """ Return a tuple with this app’s defined appspaces """
+        return tuple(self.modules.keys())
+    
+    def __repr__(self):
+        return stringify(self,
+                    type(self).fields,
+                         try_callables=False)
+
+# Sort this out once (when the module loads) instead of each
+# and every fucking time a PerApp instance is to get repr’d:
+PerApp.fields = tuple(field.name for field in fields(PerApp))
+
+class PolymerType(dict):
+    
+    """ One-off custom ‘dict’ subclass for indexing the per-app
+        registry of class-module-related subtypes – the specific
+        Finder, Loader, and Module(s) related to any given app
+    """
+    
+    def store(self, appname, loader, finder, **modules):
+        """ Create and store a ‘PerApp’ record in the PolymerType
+            dictionary index.
+        """
+        self[appname] = PerApp(loader=loader,
+                               finder=finder,
+                              modules=modules,
+                              appname=appname)
+        return self[appname]
+    
+    def add_module(self, appname, appspace, module):
+        """ Add a “clu.importing.ModuleBase” subtype to a given
+            ‘PerApp’ record already existent in the PolymerType
+            dictionary index.
+        """
+        if not appspace:
+            raise ValueError("an appspace is required")
+        if not module:
+            raise ValueError("a module is required")
+        if not self.get(appname, None):
+            raise ValueError(f"no PerApp instance for appname: {appname}")
+        if appspace in self[appname].appspaces():
+            raise NameError(f"module already exists in “{appname}” for appspace: {appspace}")
+        self[appname].modules.update({ appspace : module })
+        return self[appname]
+
+# The per-appname subtype registry dictionary:
+polymers = PolymerType()
+
 def installed_appnames():
     """ Return a set of the appnames for all installed finders
         that have one defined.
     """
-    # { finder.appname for finder in sys.meta_path if hasattr(finder, 'appname') }
     appnames = set()
     for finder in sys.meta_path:
         if hasattr(finder, 'appname'):
             appnames.add(finder.appname)
     return appnames
 
+def initialize_module(appname, appspace, loader):
+    """ Private helper for “initialize_types(…)” """
+    
+    class Module(ModuleBase, appname=appname,
+                             appspace=appspace):
+        __loader__ = loader
+    
+    return Module
+
+def initialize_new_types(appname, appspace):
+    """ Private helper for “initialize_types(…)” """
+    
+    class Loader(LoaderBase, appname=appname):
+        pass
+    
+    class Finder(FinderBase, appname=appname):
+        __loader__ = Loader
+        loader = Loader()
+    
+    Module = initialize_module(appname,
+                               appspace,
+                               Finder.loader)
+    
+    return Module, Finder, Loader
+
 @export
 def initialize_types(appname, appspace='app'):
     """ Initialize subtypes of FinderBase, LoaderBase, and ModuleBase,
@@ -546,16 +670,25 @@ def initialize_types(appname, appspace='app'):
         to subclass Module to create your class-modules, or b) import
         the ‘Module’ class from elsewhere and subclass it subsequently.
     """
+    try:
+        perapp = polymers[appname]
     
-    class Loader(LoaderBase, appname=appname):
-        pass
+    except KeyError:
+        Module, Finder, Loader = initialize_new_types(appname, appspace)
+        polymers.store(appname, loader=Loader,
+                                finder=Finder,
+                        **{ appspace : Module })
     
-    class Finder(FinderBase, appname=appname):
-        loader = Loader()
-    
-    class Module(ModuleBase, appname=appname,
-                             appspace=appspace):
-        __loader__ = Finder.loader
+    else:
+        Loader = perapp.loader
+        Finder = perapp.finder
+        Module = perapp.modules.get(appspace, None)
+        
+        if Module is None:
+            Module = initialize_module(appname, appspace, perapp.finder.loader)
+            polymers.add_module(appname=appname,
+                               appspace=appspace,
+                                 module=Module)
     
     if appname not in installed_appnames():
         sys.meta_path.append(Finder)
@@ -567,13 +700,48 @@ Module, Finder, Loader = initialize_types(consts.PROJECT_NAME)
 @export
 class ChainModuleMap(clu.dicts.ChainMap):
     
-    """ Custom “clu.dicts.ChainMap” subclass, tailored for module dicts """
+    """ Custom “clu.dicts.ChainMap” subclass, tailored for module dicts.
+        
+        In addition to the arguments accepted by its ancestor, one may
+        pass in a sequence of functions as a keyword argument “fallbacks”.
+        Each of these functions should accept exactly one argument –
+        a mapping key string – and either return something for it, or
+        raise either an AttributeError or a KeyError.
+        
+        … This is meant to allow one to pass in one or more module-level
+        “__getattr__(…)” functions, “Mapping.__missing__(…)” methods, or
+        similar callables – the ChainModuleMap “__missing__(…)” method
+        itself will attempt to invoke these functions in order, should
+        it be called upon (hence the name “fallbacks”).
+    """
+    
+    __slots__ = tuplize('fallbacks')
+    
+    def __init__(self, *dicts, fallbacks=None, **overrides):
+        super().__init__(*dicts, **overrides)
+        self.fallbacks = fallbacks or tuple()
     
     def __iter__(self):
         yield from filter(lambda item: item not in consts.BUILTINS,
                           super().__iter__())
     
+    def __getitem__(self, key):
+        # Use “item_search(…)” in order to only trigger a constituent
+        # maps’ “__missing__(…)” method within our own “__missing__(…)”
+        # function call:
+        return item_search(key, *self.maps, default=None) \
+            or self.__missing__(key)
+    
     def __missing__(self, key):
+        # “self.fallbacks” should be populated with any module-level
+        # “__getattr__(…)” functions, mapping “__missing__(…)” instance-
+        # member methods, as extracted from targets – or custom callables
+        # with identical signatures and exception-raising characteristics:
+        for fallback in self.fallbacks:
+            try:
+                return fallback(key)
+            except (AttributeError, KeyError):
+                continue
         if key in self:
             return 0
         raise KeyError(key)
@@ -582,28 +750,138 @@ class ChainModuleMap(clu.dicts.ChainMap):
         from pprint import pformat
         return pformat(dict(zip(self, (self[item] for item in self))))
 
-# Define out-of-line target-processing function:
+# Define an out-of-line target-processing function:
 def add_targets(instance, *targets):
     """ Out-of-line, use-twice-and-destroy function for processing targets """
+    
+    # Ensure the necessary lists have been established on the proxy:
     if getattr(instance, 'target_dicts', None) is None:
         instance.target_dicts = []
     if getattr(instance, 'target_lists', None) is None:
         instance.target_lists = []
+    if getattr(instance, 'target_funcs', None) is None:
+        instance.target_funcs = []
+    
+    # Iterate over targets, acting accordingly:
     for target in targets:
         if target is None:
             continue
-        if ismodule(target):
-            instance.target_dicts.append(target.__dict__)
-            instance.target_lists.append(dir(target))
+        
+        # Extract and flatten any proxy sub-module contents:
+        if isinstance(target, ProxyModule):
+            for mapping in target.__proxies__.maps:
+                if mapping not in instance.target_dicts:
+                    instance.target_dicts.append(mapping)
+            for name in target.__filters__:
+                if name not in instance.target_lists:
+                    instance.target_lists.append(name)
+            for function in target.__proxies__.fallbacks:
+                if function not in instance.target_funcs:
+                    instance.target_funcs.append(function)
             continue
+        
+        # Use the module’s “__dict__”, “dir(…)” output,
+        # and “__getattr__(…)” function (if any):
+        if ismodule(target):
+            if target.__dict__ not in instance.target_dicts:
+                instance.target_dicts.append(target.__dict__)
+                instance.target_lists.append(dir(target))
+            if hasattr(target, '__getattr__'):
+                if target.__getattr__ not in instance.target_funcs:
+                    instance.target_funcs.append(target.__getattr__)
+            continue
+        
+        # Use the mapping itself, a listification of its keys,
+        # and “__missing__(…)” method (if any):
         if ismapping(target):
-            instance.target_dicts.append(target)
-            instance.target_lists.append(list(target.keys()))
+            if target not in instance.target_dicts:
+                instance.target_dicts.append(target)
+                instance.target_lists.append(list(target.keys()))
+            if hasattr(target, '__missing__'):
+                if target.__missing__ not in instance.target_funcs:
+                    instance.target_funcs.append(target.__missing__)
+            continue
+        
+        # Simply stow any callables as fallback functions:
+        if callable(target):
+            if target not in instance.target_funcs:
+                instance.target_funcs.append(target)
             continue
 
 @export
 class ProxyModule(Module):
     
+    """ A ProxyModule is a specific type of module: one that wraps one or
+        more other things and surfaces their attributes, as if they are all
+        one big unified module.
+        
+        In this case, “things” can be modules, mappings, or callables – the
+        ProxyModule employs a bespoke ChainMap subclass to keep these varied
+        targets in order, for idempotent access with deterministic ordering,
+        like in a way that ought not surprise or scare anybody.
+        
+        Callable targets are fallbacks – they are invoked by the “__missing__”
+        method of the internal ChainMap, when attribute lookup across all of
+        the module and mapping proxy targets is exhaustively unsuccessful.
+        
+        Here’s a basic example of a ProxyModule definition:
+        
+            overrides = dict(…)
+            from yodogg.app import base_module
+            from yodogg.utils import misc as second_module
+            from yodogg.utils.functions import default_factory
+            
+            class myproxy(ProxyModule):
+                targets = (overrides, base_module,
+                                    second_module,
+                                  default_factory)
+        
+        … which after defining that, you’d use it like so – assuming your app
+        is called “yodogg” with a default “app” appspace (see “ModuleBase” for
+        more on these terms):
+        
+            from yodogg.app import myproxy
+            myproxy.attrib # searches overrides, base_module and second_module
+                           # in sequence, looking for the 'attrib' value
+            dir(myproxy)   # returns a list of the union of available stuff,
+                           # across the proxy modules’ targets
+            myproxy.NOATTR # unknown attributes will be forwarded to each
+                           # module-level “__getattr__(…)” function, dictionary
+                           # “__missing__(…)” method, or callable target found,
+                           # in turn, if the attribute search proves exhaustive
+        
+        … you can, in the modules’ definition, include other stuff besides the
+        class-level “targets” tuple; other elements added to the proxy will
+        behave like elements of any other class-based module.
+    """
+    
+    def __new__(cls, name, *targets, doc=None):
+        """ Allocate a new tabula-rasa proxy-module instance.
+            
+            Adds any targets passed in when the constructor was called –
+            which that should be like never, except maybe under testing
+            or somesuch – for the most part, ProxyModule targets’ll be
+            specified as a class-level tuple attribute.
+            
+            See the main class docstring for the deets.
+        """
+        # Call up, creating the instance:
+        instance = super(ProxyModule, cls).__new__(cls)
+        
+        # Fill in our “slots” with empty structs:
+        instance.__filters__ = []
+        instance.__proxies__ = {}
+        instance.target_dicts = []
+        instance.target_lists = []
+        instance.target_funcs = []
+        
+        # Process any targets with which this instance
+        # may have been constructed:
+        add_targets(instance, *targets)
+        
+        # Return the new instance:
+        return instance
+    
     def __init__(self, name, *targets, doc=None):
         """ Initialize a proxy-module instance.
             
@@ -613,47 +891,47 @@ class ProxyModule(Module):
             module definition – with the optional addition of zero-to-N
             “targets”.
             
-            Each target so named can be either a mapping-ish type, or a
-            module. The proxy module will then use the list of targets
-            – considerate of order – to construct a “clu.dicts.ChainMap”
-            instance that pulls, in turn, from the target list.
+            Each target so named can be either a mapping-ish type, a
+            module, or a callable. The proxy module will then use the
+            list of targets – considerate of order – to construct a
+            custom “clu.dicts.ChainMap” instance that pulls, in turn,
+            from the target list (and falling back to results from any
+            callable targets after exhausting said list).
             
             Attribute lookup on the proxy module instance will follow
             along through the “ChainMap” instances’ internal stack of
             mappings.
         """
-        # in case of __dir__(…) access before execution:
-        if not hasattr(self, '__proxies__'):
-            self.__proxies__ = {}
-        if not hasattr(self, '__filters__'):
-            self.__filters__ = []
-        
-        # Establish a base list of target dicts, and call up:
-        self.target_dicts = []
-        self.target_lists = []
+        # Super-initialize:
         super(ProxyModule, self).__init__(name, doc=doc)
         
         # Get a reference to the module class:
         cls = type(self)
         
-        # Process any targets with which this instance
-        # may have been constructed:
-        add_targets(self, *targets)
-        
-        # Process and strip off class-level “targets” 
-        # list attribute, if it exists:
-        if hasattr(cls, 'targets'):
-            add_targets(self, *cls.targets)
-            delattr(cls, 'targets')
+        # Process and strip off a class-level “targets”
+        # list attribute – if such a thing exists – and
+        # then sequester said “targets” attribute behind
+        # an underscore, if necessary:
+        if anyattrs(cls, 'targets', '_targets'):
+            add_targets(self, *attr(cls, 'targets', '_targets'))
+            if hasattr(cls, 'targets'):
+                # This type of defensive programming is necessary due to
+                # how module “__init__(…)” methods are nondeterministically
+                # subject to being called more than once:
+                setattr(cls, '_targets', attr(cls, 'targets', '_targets'))
+                delattr(cls, 'targets')
     
     def __execute__(self):
-        # Create the internal “clu.dicts.ChainMap” subclass instance:
-        self.__proxies__ = ChainModuleMap(*self.target_dicts)
+        # Create the internal “clu.dicts.ChainMap” subclass instance,
+        # and pre-combine any “__dir__”-value lists we may be using:
         self.__filters__ = tuple(iterchain(self.target_lists))
+        self.__proxies__ = ChainModuleMap(*self.target_dicts,
+                        fallbacks=tuplize(*self.target_funcs))
         
         # Further unclutter the module namespace:
         delattr(self, 'target_dicts')
         delattr(self, 'target_lists')
+        delattr(self, 'target_funcs')
         
         # Call up:
         super().__execute__()
@@ -672,13 +950,13 @@ class ProxyModule(Module):
         # attempt to get one or another nonexistant attributes from ‘self’.
         try:
             if not self.__dict__.get('_executed', False):
-                raise KeyError(key)
+                raise KeyError(f"Access attempt on uninitialized proxy module: {key}")
             elif key in consts.BUILTINS:
-                raise KeyError(key)
+                raise KeyError(f"No builtin access on proxy modules: {key}")
             return self.__proxies__[key]
-        except KeyError:
+        except KeyError as exc:
             typename = type(self).__name__
-            raise AttributeError(f"‘{typename}’ proxy module has no attribute ‘{key}’")
+            raise AttributeError(f"‘{typename}’ access failure for {key}: «{exc!s}»")
 
 export(Module, name='Module')
 export(Finder, name='Finder')
@@ -689,11 +967,17 @@ __all__, __dir__ = exporter.all_and_dir()
 
 def test():
     
-    from clu.testing.utils import inline, pout
-    from pprint import pprint
+    from clu.testing.utils import inline
+    from pprint import pprint, pformat
+    
+    @inline.precheck
+    def show_python_executable():
+        """ Show the Python executable """
+        print("PYTHON:", sys.executable)
     
     @inline
     def test_one():
+        """ Class-module basics """
         
         m = Module(consts.PROJECT_NAME)
         assert m
@@ -701,11 +985,10 @@ def test():
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
         assert nameof(m) == consts.PROJECT_NAME
-        print(nameof(m))
-        print(m.__name__)
     
     @inline
     def test_two():
+        """ Class-module subtype basics """
         
         class OtherModule(ModuleBase):
             pass
@@ -726,14 +1009,20 @@ def test():
     
     @inline
     def test_three():
-        assert pout
+        """ Class-module registry basics """
         
-        pout.v(all_registered_appnames())
-        pout.v(all_registered_modules())
+        print("all_registered_appnames():")
+        pprint(all_registered_appnames())
+        print()
+        
+        print("all_registered_modules():")
+        pprint(all_registered_modules())
+        print()
         
         m = Module(consts.PROJECT_NAME)
         
         assert len(Registry.monomers) > 0
+        
         try:
             assert len(m.monomers) == 0
         except AttributeError:
@@ -741,17 +1030,23 @@ def test():
         else:
             pass
         
-        pout.v(m.__dict__)
+        # pout.v(m.__dict__)
+        # print("m.__dict__:")
+        # pprint(m.__dict__)
         
         assert m.appname == consts.PROJECT_NAME
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
         assert nameof(m) == consts.PROJECT_NAME
         
-        pout.v(mro(m))
+        # pout.v(mro(m))
+        print("mro(m):")
+        pprint(mro(m))
+        print()
     
     @inline
-    def three_and_a_half():
+    def test_three_point_five():
+        """ System import hooks, specs and finders """
         finder = Finder()
         assert type(finder.loader) is Loader
         assert type(finder) in sys.meta_path
@@ -759,16 +1054,23 @@ def test():
         class FindMe(Module):
             pass
         
-        spec = finder.find_spec('clu.app.FindMe', [])
-        assert spec.name == 'clu.app.FindMe'
+        spec0 = finder.find_spec('clu.app.FindMe', [])
+        assert spec0.name == 'clu.app.FindMe'
         
-        module = finder.loader.create_module(spec)
-        assert type(module) is FindMe
+        module0 = finder.loader.create_module(spec0)
+        # assert type(module0) is FindMe
+        assert isinstance(module0, Module)
         
-        pout.v(mro(finder))
+        module1 = finder.loader.create_module(spec0)
+        # assert type(module1) is FindMe
+        assert isinstance(module1, Module)
+        
+        spec1 = finder.find_spec('clu.app.FindMe', [])
+        assert spec1.name == 'clu.app.FindMe'
     
     @inline
     def test_four():
+        """ Class-module subclass properties, methods, and exporting """
         
         class Derived(Module):
             
@@ -788,28 +1090,35 @@ def test():
         
         from clu.app import Derived as derived
         
-        assert type(derived) is Derived
+        # assert type(derived) is Derived
+        assert isinstance(derived, Module)
         assert derived.yo == 'dogg'
         
         for attname in dir(derived):
             assert hasattr(derived, attname)
         
-        pout.v(dir(derived))
-        pout.v(derived.exporter.exports())
+        print("dir(derived):")
+        pprint(dir(derived))
+        print()
+        
+        print("derived.exporter.exports():")
+        pprint(derived.exporter.exports())
+        print()
         
         assert type(derived.exporter).__name__ == 'Exporter'
     
     @inline
     def test_five():
+        """ Proxy-module properties and value resolution """
         
         overrides = dict(PROJECT_NAME='yodogg',
                          PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
                          BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
         
-        class testing_overridden_consts(ProxyModule):
+        class TestOverrideConstsProxy(ProxyModule):
             targets = (overrides, consts)
         
-        from clu.app import testing_overridden_consts as overridden
+        from clu.app import TestOverrideConstsProxy as overridden
         
         assert overridden.USER == consts.USER
         assert overridden.BUILTINS == consts.BUILTINS
@@ -819,15 +1128,152 @@ def test():
         
         assert not hasattr(overridden, 'targets')
         assert not hasattr(overridden, 'target_dicts')
+        assert hasattr(overridden, '_targets')
+    
+    @inline
+    def test_five_point_five():
+        """ Proxy-module fallback callable check """
         
-        # pout.v(overridden)
-        pprint(overridden.__proxies__)
+        overrides = dict(PROJECT_NAME='yodogg',
+                         PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
+                         BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
         
-        # return tuple(overridden.exporter.exports())
-        return dir(overridden)
+        def fallback_function(key):
+            if key.isupper():
+                return f"NO DOGG: {key}"
+            raise KeyError(key)
+        
+        class TestOverrideConstsFallbackProxy(ProxyModule):
+            targets = (overrides, consts, fallback_function)
+        
+        from clu.app import TestOverrideConstsFallbackProxy as overridden
+        
+        assert overridden.USER == consts.USER
+        assert overridden.BUILTINS == consts.BUILTINS
+        assert overridden.PROJECT_NAME == 'yodogg'
+        assert overridden.PROJECT_PATH.endswith('yodogg')
+        assert overridden.BASEPATH.endswith('yodogg')
+        
+        assert overridden.NOATTR == "NO DOGG: NOATTR"   # uppercase: triggers fallback
+        
+        assert not hasattr(overridden, 'targets')       # lowercase: fallback raises KeyError
+        assert not hasattr(overridden, 'target_dicts')  # lowercase: fallback raises KeyError
+        assert hasattr(overridden, '_targets')          # attribute found normally
+    
+    @inline
+    def test_six():
+        """ Polymer-type caching and “initialize_types(…)” checks """
+        
+        Module0, Finder0, Loader0 = initialize_types(consts.PROJECT_NAME)
+        
+        assert Finder is Finder0
+        assert Loader is Loader0
+        assert Module is Module0
+        assert Finder0.__loader__ is Loader0
+        assert isinstance(Module0.__loader__, Loader0)
+        assert isinstance(Finder0.loader, Loader0)
+        
+        Module1, Finder1, Loader1 = initialize_types(consts.PROJECT_NAME, appspace='aux')
+        
+        assert Finder is Finder1
+        assert Loader is Loader1
+        assert Module is not Module1 # DIFFERENT!!!
+        assert Finder1.__loader__ is Loader1
+        assert isinstance(Module1.__loader__, Loader1)
+        assert isinstance(Finder1.loader, Loader1)
+        
+        from clu.aux import Module as aux_module # Note how this is the things’ actual name,
+                                                 # “Module”, and not just what we called it,
+                                                 # «Module1» …ooof.
+        
+        assert type(aux_module) is Module1
+        
+        # print()
+        # print("AUX MODULE TYPE:", type(aux_module))
+        # print("AUX MODULE REPR:", repr(aux_module))
+        # print()
+    
+    @inline
+    def test_six_point_five():
+        """ “PerApp” dataclass and module cache check """
+        
+        appnames = all_registered_appnames()
+        # appcount = len(appnames)
+        
+        for appname in appnames:
+            
+            assert appname in polymers
+            assert appname in monomers
+            
+            per_app = polymers[appname]
+            modules = monomers[appname]
+            
+            for appspace, module_base in per_app.modules.items():
+                assert module_base.qualname in modules
+                assert module_base.qualname.startswith(dotpath_join(appname, appspace))
+            
+            for module_info in per_app.finder.iter_modules():
+                module_spec = per_app.finder.find_spec(module_info.name, [])
+                assert module_info.name in modules
+                assert module_spec.name == module_info.name
+                assert modules[module_info.name].qualname.startswith(module_spec.origin)
+            
+            # This will fail unless we try it after the “find_spec(…)” business above:
+            for module_base in per_app.modules.values():
+                assert module_base.qualname in FinderBase.specs
+                assert module_base.qualname in FinderBase.cache
+    
+    @inline.diagnostic
+    def show_spec_cache():
+        speccount = len(FinderBase.specs)
+        plural = (speccount == 1) and "spec" or "specs"
+        
+        print(f"SPEC CACHE ({speccount} {plural} total):")
+        # pprint(FinderBase.specs, indent=4)
+        
+        for specname in sorted(FinderBase.specs.keys()):
+            spec = FinderBase.specs[specname]
+            string = pformat(spec.__dict__, indent=4)
+            print()
+            print(f"    «{specname}»")
+            print(f"{string}")
+    
+    @inline.diagnostic
+    def show_monomers():
+        """ Show all registered Module subclasses """
+        appnames = all_registered_appnames()
+        appcount = len(appnames)
+        plural = (appcount == 1) and "app" or "apps"
+        print(f"MONOMERS ({appcount} {plural} total):")
+        
+        for appname in appnames:
+            monos = dict(monomers[appname])
+            monocount = len(monos)
+            monoplural = (monocount == 1) and "monomer" or "monomers"
+            string = pformat(monos, indent=4)
+            print()
+            print(f"    «{appname}» ({monocount} {monoplural}):")
+            print(f"{string}")
+    
+    @inline.diagnostic
+    def show_polymers():
+        """ Show per-app class-module-related subclasses """
+        appnames = all_registered_appnames()
+        appcount = len(appnames)
+        plural = (appcount == 1) and "app" or "apps"
+        print(f"POLYMERS ({appcount} {plural} total):")
+        
+        for appname in appnames:
+            perapp = polymers[appname]
+            modcount = len(perapp.modules)
+            modplural = (modcount == 1) and "module" or "modules"
+            string = pformat(perapp.__dict__, indent=4)
+            print()
+            print(f"    «{appname}» ({modcount} {modplural}):")
+            print(f"{string}")
     
     # Run all tests:
-    inline.test()
+    inline.test(100)
 
 if __name__ == '__main__':
     test()
\ No newline at end of file
