@@ -1,14 +1,21 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 from itertools import chain
+from reprlib import recursive_repr
 
 iterchain = chain.from_iterable
+recursive = recursive_repr(fillvalue="…")
 
-from clu.constants.consts import ENCODING
+from clu.constants import consts
 from clu.predicates import (ismetaclass, typeof,
                             resolve, attr,
-                            isenum, enumchoices, hoist, pyname)
-from clu.typology import isnumeric, isbytes, isstring, issingleton
+                            isenum, enumchoices, hoist,
+                            pyname)
+
+from clu.typology import (isnumeric, isbytes, isstring,
+                          ismapping, issequence,
+                          issingleton)
+
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
@@ -20,17 +27,27 @@ typename_hexid = lambda thing: (pyname(typeof(thing)), hex(id(thing)))
 
 INSTANCE_DELIMITER = '@'
 
+@recursive
 def strfield(value):
     """ Basic, simple, straightforward type-switch-based sub-repr """
+    from clu.typespace.namespace import nsrepr, isnamespace
     T = type(value)
-    if isstring(T):
+    if isnamespace(T):
+        return nsrepr(value)
+    elif isstring(T):
         return f"“{value}”"
     elif issingleton(T):
         return f"«{value!s}»"
     elif isnumeric(T):
         return f"{value!s}"
     elif isbytes(T):
-        return strfield(value.decode(ENCODING))
+        return strfield(value.decode(consts.ENCODING))
+    elif issequence(T):
+        contents = ", ".join(strfield(item) for item in value)
+        return f"[ {contents} ]"
+    elif ismapping(T):
+        contents = strfields(None, tuple(), try_callables=False, **value)
+        return f"{{ {contents} }}"
     elif ismetaclass(T):
         if isenum(value):
             typename, hex_id = typename_hexid(value)
@@ -88,6 +105,25 @@ def strfields(instance, fields,
             attrs[field] = strfield(field_value)
     return ", ".join(f'{k}={v}' for k, v in attrs.items()) or "…"
 
+@export
+def fullrepr(instance, string):
+    """ Return a “full-repr” string for an instance and a given string.
+        
+        For example, in the case of the following repr-stle string:
+        
+            TypeName(fieldname="val", otherfieldname="otherval") @ 0x0FE
+        
+        …the parameter “string” is the portion if the full-repr string
+        that reads:
+        
+            “fieldname="val", otherfieldname="otherval"”
+        
+        … whereas the ‘TypeName’ and hex-ID portions are derived from
+        the “instance” parameter.
+    """
+    typename, hex_id = typename_hexid(instance)
+    return f"{typename}({string}) {INSTANCE_DELIMITER} {hex_id}"
+
 @export
 def stringify(instance, fields,
                        *extras, try_callables=True,
@@ -118,8 +154,7 @@ def stringify(instance, fields,
     attr_string = strfields(instance, fields,
                                      *extras, try_callables=try_callables,
                                     **attributes)
-    typename, hex_id = typename_hexid(instance)
-    return f"{typename}({attr_string}) {INSTANCE_DELIMITER} {hex_id}"
+    return fullrepr(instance, attr_string)
 
 @export
 def chop_instance_repr(instance):
@@ -127,7 +162,7 @@ def chop_instance_repr(instance):
         an instance repr string
     """
     instance_repr = isstring(instance) and instance or repr(instance)
-    return instance_repr.split(INSTANCE_DELIMITER).pop(0).strip()
+    return instance_repr.rsplit(INSTANCE_DELIMITER).pop(0).strip()
 
 @export
 def compare_instance_reprs(repr0, *reprX):
