@@ -7,7 +7,11 @@ import pytest
 class TestConfigKeyMaps(object):
     
     def test_nested_and_flat_KeyMaps(self):
-        from clu.config.defg import Nested, KeyMapKeysView, KeyMapItemsView, KeyMapValuesView
+        from clu.config.defg import (Nested, KeyMapKeysView,
+                                             KeyMapItemsView,
+                                             KeyMapValuesView, NamespaceWalkerKeysView,
+                                                               NamespaceWalkerItemsView,
+                                                               NamespaceWalkerValuesView)
         
         tree = {
             'yo'        : "dogg",
@@ -41,9 +45,9 @@ class TestConfigKeyMaps(object):
                                           'dogggggg', 'dogggggggggg', 'dogggggg', 'dogggggggggg')
         assert tuple(nested.namespaces()) == ('nodogg', 'wat')
         
-        assert type(nested.keys()) is KeyMapKeysView
-        assert type(nested.values()) is KeyMapValuesView
-        assert type(nested.items()) is KeyMapItemsView
+        assert type(nested.keys()) is NamespaceWalkerKeysView
+        assert type(nested.values()) is NamespaceWalkerValuesView
+        assert type(nested.items()) is NamespaceWalkerItemsView
         
         flat = nested.flatten().freeze()
         
